import React, { useEffect, useRef } from "react";
import * as THREE from "three";
import { STLLoader } from "three/examples/jsm/loaders/STLLoader";
import { OrbitControls } from "three/examples/jsm/controls/OrbitControls";
import {
  autoScale,
  createEnclosedGeometry,
  getOffsetTriangles,
  getTriangleVertexs,
} from "./util";

export const STLViewer: React.FC = () => {
  const containerRef = useRef<HTMLDivElement>(null);

  useEffect(() => {
    if (containerRef.current) {
      const width = containerRef.current.clientWidth;
      const height = containerRef.current.clientHeight;

      // 创建场景、相机和渲染器
      const scene = new THREE.Scene();
      const camera = new THREE.PerspectiveCamera(75, width / height, 0.1, 1000);
      camera.position.z = 5;

      const renderer = new THREE.WebGLRenderer({ antialias: true });
      renderer.setSize(width, height);
      containerRef.current.appendChild(renderer.domElement);

      // 加载STL文件
      const loader = new STLLoader();
      loader.load("/1.stl", (geometry) => {
        const s = autoScale(geometry);
        // geometry.center();
        // const material = new THREE.MeshPhongMaterial({
        //   color: "lightgrey", // 使用更亮的颜色
        //   shininess: 100, // 增加亮度
        //   specular: 0x222222, // 调整镜面高光的颜色
        //   // side: THREE.DoubleSide,
        //   // wireframe: true,
        // });
        // const mesh = new THREE.Mesh(geometry, material);
        // mesh.scale.set(scale, scale, scale);
        // scene.add(mesh);

        // 输出三角形顶点信息
        const triangles = getTriangleVertexs(geometry);
        ////////////////////////////////////////////////////////////////
        ////////////////////////////////////////////////////////////////
        ////////////////////////////////////////////////////////////////
        ////////////////////////////////////////////////////////////////

        const newTriangles = getOffsetTriangles(triangles, -2);

        console.log("newTriangles", newTriangles);

        // 使用上面定义的函数
        const enclosedGeometry = createEnclosedGeometry(
          triangles,
          newTriangles
        );

        enclosedGeometry.center();

        const material = new THREE.MeshBasicMaterial({
          color: "lightgrey",
          side: THREE.DoubleSide,
        });

        const mesh = new THREE.Mesh(enclosedGeometry, material);
        mesh.scale.set(s, s, s);
        scene.add(mesh);

        ////////////////////////////////////////////////////////////////
        ////////////////////////////////////////////////////////////////
        ////////////////////////////////////////////////////////////////
        ////////////////////////////////////////////////////////////////
      });

      // 添加环境光源
      const ambientLight = new THREE.AmbientLight(0xffffff, 1); // 第二个参数为强度
      scene.add(ambientLight);

      // 添加方向光源
      const directionalLight = new THREE.DirectionalLight(0xffffff, 2);
      directionalLight.position.set(1, 1, 1).normalize();
      scene.add(directionalLight);

      // 添加XYZ轴
      const axesHelper = new THREE.AxesHelper(2);
      scene.add(axesHelper);

      // 添加OrbitControls
      const controls = new OrbitControls(camera, renderer.domElement);

      // 渲染函数
      const animate = () => {
        requestAnimationFrame(animate);
        renderer.render(scene, camera);
      };

      animate();
    }
  }, []);

  return <div ref={containerRef} style={{ width: "100vw", height: "100vh" }} />;
};
