import { useEffect, useState } from "react";
import { useDomain } from "@/hook/useDomain";
import { Button, Space, Table, Tooltip } from "antd";
import { columns } from "./columns";
import { DesktopOutlined, TagOutlined } from "@ant-design/icons";
import { openOHIFViewer } from "@/modules/Admin/Dicom/Upload/util";

interface ArchiveListProps {
  children?: JSX.Element;
}

export const ArchiveList = (props: ArchiveListProps) => {
  const [dataSource, setDataSource] = useState<any>([]);
  const [tableLoading, setTableLoading] = useState(false);
  const { userDomainService } = useDomain();

  useEffect(() => {
    userDomainService.findArchiveTask().then((res) => {
      const { code, data } = res;
      if (code === 0) {
        setDataSource(data);
      }
      setTableLoading(false);
    });
  }, [userDomainService]);

  const onViewDicom = (record: any) => {
    const { StudyInstanceUID, SeriesInstanceUID } = record;
    openOHIFViewer(StudyInstanceUID, SeriesInstanceUID);
  };

  return (
    <div>
      <Table
        dataSource={dataSource}
        loading={tableLoading}
        columns={[
          ...columns,
          {
            title: "操作",
            dataIndex: "operation",
            render: (_: any, record: any) => (
              <Space>
                <Tooltip title="在线阅片">
                  <Button
                    type="text"
                    icon={<DesktopOutlined />}
                    onClick={() => onViewDicom(record)}
                  />
                </Tooltip>
                <Tooltip title="添加标签">
                  <Button
                    type="text"
                    icon={<TagOutlined />}
                    onClick={() => {}}
                  />
                </Tooltip>
              </Space>
            ),
          },
        ]}
        rowKey="id"
      />
    </div>
  );
};
